#yoast_panel #yoast_results_readability,#yoast_panel #yoast_results_seo{margin:50px 0;display:inline-block}#yoast_panel .icon-cross{color:red}#yoast_panel .icon-tick{color:green}#yoast_panel li{margin-bottom:10px}
