RICH_TEXT_FEATURES = [
    'h1',
    'h2',
    'h3',
    'h4',
    'bold',
    'italic',
    'link',
    'ol',
    'ul',
]

URL_IMAGE_MOCK_1 = \
    """
    https://media.wagtail.io/images/w2.original.original_Xk3v8T2.width-700.png
    """

TEXT_1 = \
    """
    <h1>This page is rated perfect with Wagtail Yoast SEO</h1>
    <p>
    Lorem ipsum dolor sit amet, consectetur adipiscing elit,
    sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
    Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris
    nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in
    reprehenderit in voluptate velit esse cillum dolore eu
    fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident,
    sunt in culpa qui officia deserunt mollit anim id est laborum.
    <p>
    """

WELCOME_TEXT = \
    """
    <h1>Welcome on Wagtail Yoast SEO</h1>
    <h2>
    Log in
    <a href="http://localhost:8080/wagtail/" target="_blank">
    Wagtail Admin
    </a>
    with :
    </h2>
    <p>Username: <kbd>wagtail</kbd></p>
    <p>Password: <kbd>yoast</kbd></p>
    """
