# Generated by Django 3.0.9 on 2020-08-30 09:17

from django.db import migrations, models
import django.db.models.deletion
import tests.blocks
import wagtail.core.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0052_pagelogentry'),
    ]

    operations = [
        migrations.CreateModel(
            name='TestPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('body', wagtail.core.fields.StreamField([('text', tests.blocks.TextBlock()), ('image', tests.blocks.ImageBlock())], blank=True)),
                ('keywords', models.CharField(blank=True, default='', max_length=100)),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
    ]
