{% load i18n %}
<ul class="objects">
    <li class="object">
        <div class="title-wrapper">
            <label>{% trans list_title %}</label>
        </div>
        <div class="object-layout">
            <div id="yoast_{{ list_id }}" class="object-layout_big-part">
                <ul class="errors"></ul>
                <ul class="success"></ul>
            </div>
        </div>
    </li>
</ul>
